@@ -28,6 +28,36 @@ d3_dep_v5 <- function(offline=TRUE){
 }
 
 
+#' 'd3.js' Dependency for Version 6
+#'
+#' @param offline \code{logical} to specify whether to use
+#'         a local copy of d3.js (\code{TRUE}) or use cdn (\code{FALSE})
+#' @return \code{htmltools::htmlDependency}
+#' @export
+#' @examples
+#' library(d3r)
+#' library(htmltools)
+#'
+#' tagList(d3_dep_v6())
+#' @family 'd3' dependency functions
+#' @seealso \code{\link{d3_dep_v5}}, \code{\link{d3_dep_v4}}, \code{\link{d3_dep_v3}},
+#'   and \code{\link{d3_dep_jetpack}}.
+d3_dep_v6 <- function(offline=TRUE){
+  if(offline) {
+    src = c(file=system.file("www/d3/v6/dist", package="d3r"))
+  } else {
+    src <- c(href="https://unpkg.com/d3@6.2.0/dist")
+  }
+
+  htmltools::htmlDependency(
+    name = "d3",
+    version = "6.2.0",
+    src = src,
+    script = "d3.min.js"
+  )
+}
+
+
 #' 'd3.js' Dependency for Version 4
 #'
 #' @param offline \code{logical} to specify whether to use
